@@ -8,6 +8,9 @@ pub struct CharacterConfig<'a> {
     pub success_symbol: &'a str,
     pub error_symbol: &'a str,
     pub vicmd_symbol: &'a str,
+    pub vimcmd_visual_symbol: &'a str,
+    pub vimcmd_replace_symbol: &'a str,
+    pub vimcmd_replace_one_symbol: &'a str,
     pub disabled: bool,
 }
 
@@ -18,6 +21,9 @@ impl<'a> Default for CharacterConfig<'a> {
             success_symbol: "[❯](bold green)",
             error_symbol: "[❯](bold red)",
             vicmd_symbol: "[❮](bold green)",
+            vimcmd_visual_symbol: "[❮](bold yellow)",
+            vimcmd_replace_symbol: "[❮](bold purple)",
+            vimcmd_replace_one_symbol: "[❮](bold purple)",
             disabled: false,
         }
     }
