@@ -38,7 +38,7 @@ pub struct Context<'a> {
     /// E.g. when navigating to a PSDrive in PowerShell, or a path without symlinks resolved.
     pub logical_dir: PathBuf,
 
-    /// A struct containing directory contents in a lookup-optimised format.
+    /// A struct containing directory contents in a lookup-optimized format.
     dir_contents: OnceCell<DirContents>,
 
     /// Properties to provide to modules.
@@ -606,7 +606,7 @@ pub struct Properties {
     #[clap(long, value_delimiter = ' ')]
     pub pipestatus: Option<Vec<String>>,
     /// The width of the current interactive terminal.
-    #[clap(short = 'w', long, default_value_t=default_width(), parse(try_from_str=parse_width))]
+    #[clap(short = 'w', long, default_value_t=default_width(), value_parser=parse_width)]
     terminal_width: usize,
     /// The path that the prompt should render for.
     #[clap(short, long)]
@@ -622,7 +622,7 @@ pub struct Properties {
     #[clap(short = 'k', long, default_value = "viins")]
     pub keymap: String,
     /// The number of currently running jobs
-    #[clap(short, long, default_value_t, parse(try_from_str=parse_jobs))]
+    #[clap(short, long, default_value_t, value_parser=parse_jobs)]
     pub jobs: i64,
 }
 
